@@ -464,27 +464,29 @@ class QueryType(object):
 
 
 def make_login_req(investor_id,
-                         trade_password,
-                         op_station,
-                         interface_type,
-                         account_type,
-                         broker_id,
-                         user_product_info='',
-                         app_id='',
-                         auth_code='',
-                         collect_info='',
-                         flow_path='',
-                         client_public_ip='',
-                         client_port='',
-                         md_op_station='',
-                         client_id='',
-                         client_info='',
-                         is_auto_confirm=False,
-                         is_sync_position=False,
-                         is_check_pwd=False,
-                         op_station_off='',
-                         qsid='',
-                         wtid=''):
+                   trade_password,
+                   op_station,
+                   interface_type,
+                   account_type,
+                   broker_id,
+                   source,
+                   user_product_info='',
+                   app_id='',
+                   auth_code='',
+                   collect_info='',
+                   flow_path='',
+                   client_public_ip='',
+                   client_port='',
+                   md_op_station='',
+                   client_id='',
+                   client_info='',
+                   is_auto_confirm=False,
+                   is_sync_position=False,
+                   is_check_pwd=False,
+                   op_station_off='',
+                   qsid='',
+                   wtid=''
+                   ):
     """
 
     Args:
@@ -563,6 +565,14 @@ def make_query_investor_req(investor_key,  # 投资者key
     return generate_req(inspect.currentframe())
 
 
+# 查询合约
+def make_query_instrument_req(investor_key,  # 投资者唯一编号
+                              exchange_id,  # 交易所代码
+                              instrument_id  # 合约代码
+                              ):
+    return generate_req(inspect.currentframe())
+
+
 # 查询投资者结算结果
 def make_query_settlement_info_req(investor_key,  # 投资者key
                                    broker_id,  # 经纪商id
@@ -855,11 +865,3 @@ class InterfaceType(object):
     APEX = 11  # 顶点
     SIMULATE = 12  # 模拟柜台
     MOCK = 13  # 模拟期货自返回
-
-
-# 查询合约
-def make_query_instrument_req(investor_key,  # 投资者唯一编号
-                              exchange_id,  # 交易所代码
-                              instrument_id  # 合约代码
-                              ):
-    return generate_req(inspect.currentframe())
