@@ -41,13 +41,16 @@ class TradeClient(object):
     '''
 
     def __init__(self, inter_service):
+        self._investor_id = None
         self._investor_key = None
         self._rpc_call = None
         self._inter_service = None
+        self._rpc_call_mf = None
         if isinstance(inter_service, Gateway):  # 暂时只支持网关接入
             self._inter_service = inter_service
             self._inter_service.set_protocol_head(chr(0x0f))
             self._rpc_call = self._inter_service.gateway_call
+            self._rpc_call_mf = self._inter_service.gateway_call_mf
         else:
             raise Exception('not supported service type')
 
@@ -116,6 +119,7 @@ class TradeClient(object):
                                                    op_station=None,
                                                    interface_type=interface_type,
                                                    account_type=trade_req.AccountType.AccountType_FUTURES,
+                                                   source=trade_req.SourceType.SourceType_Trader,
                                                    broker_id=None,
                                                    user_product_info=None,
                                                    app_id=None,
@@ -137,17 +141,22 @@ class TradeClient(object):
             ant.log_err(e)
             return False
 
-        req = account_req.make_login_req(login=trade_login_req, qsid=qsid, wtid=wtid)
+        req = account_req.make_login_req(
+            login=trade_login_req, qsid=qsid, wtid=wtid)
 
         ret, rsp = self._rpc_call(SERVICE_ACCOUNT, METHOD_ACCOUNT_LOGIN, req)
 
         if ret == 0:
             self._investor_key = rsp['login']['investor_key']
+            self._investor_id = investor_id
             return True
         else:
             ant.log_err('login failed, err_code:%d, err_msg:%s', ret, rsp)
             return False
 
+    def create_condition_service(self):
+        return self._inter_service, self._investor_id, self._investor_key
+
     def logout(self):
         '''
         账号登出
@@ -155,7 +164,8 @@ class TradeClient(object):
         if self._investor_key is None:
             return -1, 'please login first!'
 
-        account_logout_req = account_req.make_logout_req(investor_key=self._investor_key)
+        account_logout_req = account_req.make_logout_req(
+            investor_key=self._investor_key)
         return self._rpc_call(SERVICE_ACCOUNT, METHOD_ACCOUNT_LOGOUT, account_logout_req)
 
     def query_asset(self,
@@ -256,12 +266,12 @@ class TradeClient(object):
 
         '''
 
-        req = trade_req.make_query_position_detail_req(investor_key=self._investor_key,
-                                                       instrument_id=instrument_id,
-                                                       exchange_id=exchange_id,
-                                                       historical_date=historical_date,
-                                                       client_id=client_id)
-        return ant.async_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_POSITION, req)
+        req = trade_req.make_query_position_req(investor_key=self._investor_key,
+                                                instrument_id=instrument_id,
+                                                exchange_id=exchange_id,
+                                                historical_date=historical_date,
+                                                client_id=client_id)
+        return self._rpc_call_mf(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_POSITION, req)
 
     def order_insert(self,
                      instrument_id,
@@ -400,8 +410,7 @@ class TradeClient(object):
                                               price_tick_num=price_tick_num)
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_CANCEL_ORDER, req)
 
-    def query_instrument(self,
-                         instrument_id):
+    def query_instrument(self, instrument_id):
         '''
         查询合约
         Args:
@@ -419,8 +428,7 @@ class TradeClient(object):
     def query_margin_rate_req(self,
                               instrument_id,
                               hedge_flag=trade_req.HedgeFlagType.HedgeFlag_Speculation,
-                              exchange_id=None
-                              ):
+                              exchange_id=None):
         '''
         查询保证金率
         Args:
@@ -440,8 +448,7 @@ class TradeClient(object):
 
     def query_commission_rate(self,
                               instrument_id,
-                              exchange_id=None
-                              ):
+                              exchange_id=None):
         '''
         查询手续费率
         Args:
@@ -496,8 +503,7 @@ class TradeClient(object):
                            client_id=None,
                            is_active=None,
                            client_id_type=None,
-                           investor_unit_id=None
-                           ):
+                           investor_unit_id=None):
         '''
         查询交易编码
         Args:
@@ -515,14 +521,12 @@ class TradeClient(object):
                                                   client_id=client_id,
                                                   is_active=is_active,
                                                   client_id_type=client_id_type,
-                                                  investor_unit_id=investor_unit_id
-                                                  )
+                                                  investor_unit_id=investor_unit_id)
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_TRADING_CODE, req)
 
     def query_investor(self,
                        broker_id,
-                       investor_id
-                       ):
+                       investor_id):
         '''
         查询投资者
         Args:
@@ -542,8 +546,7 @@ class TradeClient(object):
                                 investor_id,
                                 trading_day=None,
                                 account_id=None,
-                                currency_id=None,
-                                ):
+                                currency_id=None, ):
         '''
         投资者结算结果确认
         Args:
@@ -630,8 +633,7 @@ class TradeClient(object):
         '''
         req = trade_req.make_user_password_update_req(investor_key=self._investor_key,
                                                       old_password=old_password,
-                                                      new_password=new_password
-                                                      )
+                                                      new_password=new_password)
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_USER_PASSWORD_UPDATE, req)
 
     def query_bank_account_money(self,
@@ -642,8 +644,7 @@ class TradeClient(object):
                                  currency_id,
                                  broker_branch_id,
                                  account,
-                                 bank_account
-                                 ):
+                                 bank_account):
         req = trade_req.make_query_bank_account_money_req(investor_key=self._investor_key,
                                                           bank_id=bank_id,
                                                           bank_branch_id=bank_branch_id,
@@ -652,6 +653,5 @@ class TradeClient(object):
                                                           currency_id=currency_id,
                                                           broker_branch_id=broker_branch_id,
                                                           account=account,
-                                                          bank_account=bank_account
-                                                          )
+                                                          bank_account=bank_account)
         return self._rpc_call(SERVICE_TRADER_FUTURES, METHOD_TRADER_QUERY_BANK_ACCOUNT_MONEY, req)
